﻿/*******************************************************************************
 * Copyright 2009 Seapine Software, Inc. All rights reserved.
 * 
 * IMPORTANT:  This Software is supplied to you by Seapine Software, Inc. (“Seapine”)
 * in consideration of your agreement to the following terms, and your use, installation,
 * modification or redistribution of this Software constitutes acceptance of these terms.
 * If you do not agree with these terms, please do not use, install, modify or redistribute
 * this Software.
 * 
 * In consideration of your agreement to abide by the following terms, and subject to these
 * terms, Seapine grants you a personal, non-exclusive license, under Seapine copyrights in
 * this original Seapine software (the “Software”), to use, reproduce, modify and redistribute
 * the Software, with or without modifications, in source and/or binary forms; provided that
 * if you redistribute the Software in its entirety and without modifications, you must retain
 * this notice and the following text and disclaimers in all such redistributions of the Software.
 * Neither the name, trademarks, service marks or logos of Seapine, Inc. may be used to endorse
 * or promote products derived from the Software without specific prior written permission from
 * Seapine.  Except as expressly stated in this notice, no other rights or licenses, express or
 * implied, are granted by Seapine herein, including but not limited to any patent rights that
 * may be infringed by your derivative works or by other works in which the Software may be
 * incorporated.
 * 
 * The Software is provided by Seapine on an "AS IS" basis.  SEAPINE MAKES NO WARRANTIES,
 * EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION THE IMPLIED WARRANTIES OF NON-INFRINGEMENT,
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE, REGARDING THE SOFTWARE OR ITS USE AND
 * OPERATION ALONE OR IN COMBINATION WITH YOUR PRODUCTS. 
 * 
 * IN NO EVENT SHALL SEAPINE BE LIABLE FOR ANY SPECIAL, INDIRECT, INCIDENTAL OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) ARISING IN ANY WAY OUT OF THE USE,
 * REPRODUCTION, MODIFICATION AND/OR DISTRIBUTION OF THE SOFTWARE, HOWEVER CAUSED AND WHETHER
 * UNDER THEORY OF CONTRACT, TORT (INCLUDING NEGLIGENCE), STRICT LIABILITY OR OTHERWISE, EVEN
 * IF SEAPINE HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ******************************************************************************/
using System;
using System.Collections;
using System.IO;
using System.Linq;
using System.Text;
using Microsoft.Office.Interop.Outlook;
using System.Windows.Forms;

namespace SCMMail
{
    class Program
    {
        static void Main(string[] args)
        {
            //Error log will be created in the same directory as where the application launches
            //This will NOT be where the file is stored, rather the directory of the Surround SCM client
            Logger.SetPath(System.Environment.CurrentDirectory);
            //Let's get the number of files selected
            String numFiles = System.Environment.GetEnvironmentVariable("SSCM_NUMFILES");
            //Must ensure at least one file is selected
            if (numFiles == null)
            {
                MessageBox.Show("You must have at least one file selected","SCMMail");
            }
            else if (numFiles.Equals("0"))
            {
                MessageBox.Show("You must have at least one file selected", "SCMMail");
            }
            else
            {
                try
                {
                    int count = Convert.ToInt16(numFiles);
                    //We need to handle things differently depending on how many files are selected
                    //One file is easy
                    if (count == 1)
                    {
                        String sDisplayName = System.Environment.GetEnvironmentVariable("SSCM_FILE");
                        String attachFile = System.Environment.GetEnvironmentVariable("SSCM_LOCALFILE");
                        FileInfo localFile = new FileInfo(attachFile);
                        if (localFile.Exists)
                        {

                            Microsoft.Office.Interop.Outlook.Application outLook = new Microsoft.Office.Interop.Outlook.Application();
                            MailItem mItem = (MailItem)outLook.CreateItem(OlItemType.olMailItem);

                            mItem.Body = " ";//if you set this to "", then it will be set to null, and the app will fail.
                            mItem.To = "";
                            mItem.Subject = "";

                            int iPosition = (int)mItem.Body.Length + 1;
                            int iAttachType = (int)OlAttachmentType.olByValue;

                            mItem.Attachments.Add(attachFile, iAttachType, iPosition, sDisplayName);
                            mItem.Display(false);
                        }
                        else
                        {
                            MessageBox.Show("The file is not in your working directory.", "SCMMail");
                        }
                    }

                    //If there are two or more files selected, it gets interesting.
                    //If two files are selected, the "separator" between the files is " and "
                    //If three or more, commas separate each file (, )
                    //So two files look like: file1 and file2
                    //Three files look like: file1, file2, file3
                    else
                    {
                        //get the list of local files (since there is more than one selected)
                        String files = System.Environment.GetEnvironmentVariable("SSCM_LOCALFILELIST");
                        //Initialize string arrays to hold the file with full path and the names of the files
                        string[] filesToAttach = new string[count];
                        string[] filesToDisplay = new string[count];
                        //If it is two files, then we will account for the word 'and' when counting how far before our
                        //index
                        if (count == 2)
                        {
                            //If working directory is on a unc path:
                            if (files.Contains("\\\\"))
                            {
                                try
                                {
                                    int index = files.LastIndexOf("\\\\");
                                    //we know there are two files, so let's parse it out
                                    string firstFile = files.Substring(0, index - 5);
                                    string firstFileName = firstFile.Substring(firstFile.LastIndexOf('\\') + 1);
                                    string secondFile = files.Substring(index);
                                    string secondFileName = secondFile.Substring(firstFile.LastIndexOf('\\') + 1);

                                    filesToAttach[0] = firstFile;
                                    filesToAttach[1] = secondFile;

                                    filesToDisplay[0] = firstFileName;
                                    filesToDisplay[1] = secondFileName;
                                }
                                catch (System.Exception fcc)
                                {
                                    Logger.WriteLine(fcc.Message);
                                }
                            }
                            //if working directory is on a local mapped letter drive
                            else
                            {
                                try
                                {
                                    int index = files.LastIndexOf(':');
                                    //we know there are two files, so let's parse it out
                                    string firstFile = files.Substring(0, index - 6);
                                    string firstFileName = firstFile.Substring(firstFile.LastIndexOf('\\') + 1);
                                    string secondFile = files.Substring(index - 1);
                                    string secondFileName = secondFile.Substring(firstFile.LastIndexOf('\\') + 1);

                                    filesToAttach[0] = firstFile;
                                    filesToAttach[1] = secondFile;

                                    filesToDisplay[0] = firstFileName;
                                    filesToDisplay[1] = secondFileName;
                                }
                                catch (System.Exception fcc)
                                {
                                    Logger.WriteLine(fcc.Message);
                                }

                            }
                        }
                        //three or more files are selected, so we will account for the word a comma when counting how far before our
                        //index
                        else
                        {
                            //If working directory is on a unc path:
                            if (files.Contains("\\\\"))
                            {
                                try
                                {
                                    int index = files.LastIndexOf("\\\\");

                                    int counter = 0;
                                    while (index > -1)
                                    {
                                        Logger.WriteLine(index.ToString());
                                        Logger.WriteLine(files);
                                        string firstFile = files.Substring(index);
                                        Logger.WriteLine(firstFile);

                                        string firstFileName = firstFile.Substring(firstFile.LastIndexOf('\\') + 1);
                                        Logger.WriteLine(firstFileName);

                                        filesToAttach[counter] = firstFile;
                                        filesToDisplay[counter] = firstFileName;

                                        counter++;
                                        if (index > 2)
                                        {
                                            files = files.Substring(0, index - 2);
                                            index = files.LastIndexOf("\\\\");
                                        }
                                        else
                                        {
                                            index = -1;
                                        }
                                    }
                                }
                                catch (System.Exception fcc)
                                {
                                    Logger.WriteLine(fcc.Message);
                                }
                            }
                            //if working directory is on a local mapped letter drive
                            else
                            {
                                try
                                {
                                    int index = files.LastIndexOf(':');
                                    int counter = 0;
                                    while (index > -1)
                                    {
                                        string firstFile = files.Substring(index - 1);
                                        string firstFileName = firstFile.Substring(firstFile.LastIndexOf('\\') + 1);
                                       
                                        filesToAttach[counter] = firstFile;
                                        filesToDisplay[counter] = firstFileName;
                                        counter++;
                                        if (index > 2)
                                        {
                                            files = files.Substring(0, index - 3);
                                            index = files.LastIndexOf(":");
                                        }
                                        else
                                        {
                                            index = -1;
                                        }
                                    }

                                }
                                catch (System.Exception fcc)
                                {
                                    Logger.WriteLine(fcc.Message);
                                }

                            }
                        }
                        //Now we check to see if the files are there:
                        bool isThere = true;
                        for (int i = 0; i < filesToAttach.Length; i++)
                        {

                            FileInfo localFile = new FileInfo(filesToAttach[i].Trim());
                            if (!(localFile.Exists))
                            {
                                isThere = false;
                            }
                        }
                        if (isThere == false)
                        {
                            MessageBox.Show("At least one of the files is not in your working directory.", "SCMMail");
                        }
                        else
                        {
                            //if the files are indeed there, we can call outlook to open a new message and attach the files
                            Microsoft.Office.Interop.Outlook.Application outLook = new Microsoft.Office.Interop.Outlook.Application();
                            MailItem mItem = (MailItem)outLook.CreateItem(OlItemType.olMailItem);
                            
                            mItem.Body = " ";//if you set this to "", then it will be set to null, and the app will fail.
                            mItem.To = "";
                            mItem.Subject = "";

                            int iPosition = (int)mItem.Body.Length + 1;
                            int iAttachType = (int)OlAttachmentType.olByValue;
                            for (int i = 0; i < filesToAttach.Length; i++)
                            {
                                string attachFile = filesToAttach[i].Trim();
                                string sDisplayName = filesToDisplay[i].Trim();
                                mItem.Attachments.Add(attachFile, iAttachType, iPosition, sDisplayName);
                            }
                            mItem.Display(false);
                        }

                    }
                }
                catch (System.Exception fcc)
                {
                    Logger.WriteLine(fcc.Message);
                }
            }
        }
    }
}
